<?php
/**
 * black white functions and definitions
 * functions.php
 * @package black white
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 900; /* pixels */

if ( ! function_exists( 'black_white_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function black_white_setup() {

	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on black white, use a find and replace
	 * to change 'black-white' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'black-white', get_template_directory() . '/languages' );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	/**
	 * Enable support for Post Thumbnails on posts and pages
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 150, 150, false );

	/**
	 * This theme uses wp_nav_menu() in one location.
	 */
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'black-white' ),
	) );

	/**
	 * Enable support for Post Formats
	 */
	add_theme_support( 'post-formats', array( 'aside', 'image', 'link', 'quote', 'status', 'video' ) );

	/**
	 * Setup the WordPress core custom background feature.
	 */
	add_theme_support( 'custom-background', apply_filters( 'black_white_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif; // black_white_setup
add_action( 'after_setup_theme', 'black_white_setup' );

/**
 * Register widgetized area and update sidebar with default widgets
 */
function black_white_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'black-white' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'black_white_widgets_init' );

/**
 * Enqueue scripts and styles
 */
function black_white_scripts() {
	wp_enqueue_style( 'black-white-style', get_stylesheet_uri() );

	wp_enqueue_script( 'black-white-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'black-white-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if ( is_singular() && wp_attachment_is_image() ) {
		wp_enqueue_script( 'black-white-keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '20120202' );
	}
}
add_action( 'wp_enqueue_scripts', 'black_white_scripts' );

	// This theme styles the visual editor with editor-style.css to match the theme style.
	// add_editor_style();

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
/**
 * Color scheme option
 * Since version 1.1
 */
add_action('admin_menu', 'bw_color_option_menu');
require get_template_directory() . '/schemes/color-option.php';
/*
 * Redirect after theme activation
 * Since version 2.1
 */
global $pagenow;
	if ( is_admin() && isset( $_GET['activated'] ) && $pagenow == 'themes.php' )
{ wp_redirect( admin_url( 'themes.php?page=schemes/color-options.php' ) );
	exit; }
/*
 * Load the color schemes options style.
 * Since version 2.2
 */
function bw_color_schemes_scripts() {
	wp_enqueue_style( 'color-schemes', get_template_directory_uri() . '/schemes/' . get_option('bw_theme_color') . '.css' );
}

add_action( 'wp_enqueue_scripts', 'bw_color_schemes_scripts' );